<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru" sourcelanguage="en">
<context>
    <name>CenterlineVectorizer</name>
    <message>
        <source>Can&apos;t vectorize a %1 level</source>
        <translation type="vanished">Не удалось векторизовать уровень %1</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a level with no frames</source>
        <translation type="vanished">Не удалось векторизовать уровень без кадров</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a %1 image</source>
        <translation type="vanished">Не удалось векторизовать изображение %1</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image or a Level</source>
        <translation type="vanished">Некорректный аргумент (%1): должно быть изображение или уровень</translation>
    </message>
</context>
<context>
    <name>FilePath</name>
    <message>
        <source>&quot;%1&quot;</source>
        <translation type="vanished">&quot;%1&quot;</translation>
    </message>
    <message>
        <source>can&apos;t concatenate an absolute path : %1</source>
        <translation type="vanished">Не может конкатенировать абсолютный путь: %1</translation>
    </message>
    <message>
        <source>%1 is not a directory</source>
        <translation type="vanished">%1 не является каталогом</translation>
    </message>
    <message>
        <source>can&apos;t read directory %1</source>
        <translation type="vanished">Не удается прочитать каталог%1</translation>
    </message>
</context>
<context>
    <name>Image</name>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation type="vanished">Файл %1 не существует</translation>
    </message>
    <message>
        <source>Loaded first frame of %1</source>
        <translation type="vanished">Загружен первый кадр %1</translation>
    </message>
    <message>
        <source>Unexpected error while reading image</source>
        <translation type="vanished">Ошибка при чтении изображения</translation>
    </message>
    <message>
        <source>Unrecognized file type :</source>
        <translation type="vanished">Нераспознанный тип файла :</translation>
    </message>
    <message>
        <source>Can&apos;t save a %1 image to this file type : %2</source>
        <translation type="vanished">Не удалось сохранить изображение %1 в этот тип файла: %2</translation>
    </message>
    <message>
        <source>Unexpected error while writing image</source>
        <translation type="vanished">Ошибка при записи изображения</translation>
    </message>
</context>
<context>
    <name>ImageBuilder</name>
    <message>
        <source>Bad argument (%1): should be &apos;Raster&apos; or ToonzRaster&apos;</source>
        <translation type="vanished">Недопустимый аргумент (%1): должен быть «Растр» или &quot;ToonzRaster&quot;</translation>
    </message>
    <message>
        <source>ImageBuilder(%1 image)</source>
        <translation type="vanished">ImageBuilder(%1 изображение)</translation>
    </message>
    <message>
        <source>%1 : %2</source>
        <translation type="vanished">%1 : %2</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be a Transformation</source>
        <translation type="vanished">Плохой аргумент (%1): должно быть преобразование</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>%1 frames</source>
        <translation type="vanished">%1 кадров</translation>
    </message>
    <message>
        <source>Bad argument (%1). It should be FilePath or string</source>
        <translation type="vanished">Недопустимый аргумент (%1). Это должен быть путь к файлу или строка</translation>
    </message>
    <message>
        <source>Exception loading level (%1)</source>
        <translation type="vanished">Уровень загрузки исключений (%1)</translation>
    </message>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation type="vanished">Файл %1 не существует</translation>
    </message>
    <message>
        <source>File %1 is unsupported</source>
        <translation type="vanished">Файл %1 не поддерживается</translation>
    </message>
    <message>
        <source>Exception reading %1</source>
        <translation type="vanished">Чтение исключений %1</translation>
    </message>
    <message>
        <source>Can&apos;t save an empty level</source>
        <translation type="vanished">Не удалось сохранить пустой уровень</translation>
    </message>
    <message>
        <source>Unrecognized file type :</source>
        <translation type="vanished">Нераспознанный тип файла :</translation>
    </message>
    <message>
        <source>Can&apos;t save a %1 level to this file type : %2</source>
        <translation type="vanished">Не удается сохранить уровень %1 для этого типа файла : %2</translation>
    </message>
    <message>
        <source>Exception writing %1</source>
        <translation type="vanished">Запись исключений %1</translation>
    </message>
    <message>
        <source>frame index (%1) must be a number</source>
        <translation type="vanished">Индекс кадра (%1) должен быть числом</translation>
    </message>
    <message>
        <source>frame index (%1) is out of range (0-%2)</source>
        <translation type="vanished">Индекс кадра (%1) вне диапазона (0-%2)</translation>
    </message>
    <message>
        <source>second argument (%1) is not an image</source>
        <translation type="vanished">Второй аргумент (%1) не является изображением</translation>
    </message>
    <message>
        <source>can not insert a %1 image into a level</source>
        <translation type="vanished">Невозможно вставить изображение %1 в уровень</translation>
    </message>
    <message>
        <source>can not insert a %1 image to a %2 level</source>
        <translation type="vanished">Невозможно  вставить изображение %1 в уровень %2</translation>
    </message>
</context>
<context>
    <name>OutlineVectorizer</name>
    <message>
        <source>Can&apos;t vectorize a %1 level</source>
        <translation type="vanished">Не удалась векторизация уровня %1</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a level with no frames</source>
        <translation type="vanished">Не удалось векторизовать уровень без кадров</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a %1 image</source>
        <translation type="vanished">Не удалось векторизовать изображение %1</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image or a Level</source>
        <translation type="vanished">Некорректный аргумент (%1): должно быть изображение или уровень</translation>
    </message>
    <message>
        <source>Invalid color : </source>
        <translation type="vanished">Недопустимый цвет : </translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="../../toonzlib/preferences.cpp" line="100"/>
        <source>Retas Level Format</source>
        <translation>Формат уровней Retas</translation>
    </message>
    <message>
        <location filename="../../toonzlib/preferences.cpp" line="106"/>
        <source>Adobe Photoshop</source>
        <translation>Adobe Photoshop</translation>
    </message>
    <message>
        <location filename="../../toonzlib/preferences.cpp" line="203"/>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../toonzlib/avicodecrestrictions.cpp" line="86"/>
        <source>No restrictions for uncompressed avi video</source>
        <translation>Нет ограничений для несжатого видео avi</translation>
    </message>
    <message>
        <location filename="../../toonzlib/avicodecrestrictions.cpp" line="93"/>
        <source>It is not possible to communicate with the codec.
 Probably the codec cannot work correctly.</source>
        <translation>Невозможно установить связь с кодеком.
  Вероятно, кодек работает неправильно.</translation>
    </message>
    <message>
        <location filename="../../toonzlib/avicodecrestrictions.cpp" line="125"/>
        <source>video width must be a multiple of %1</source>
        <translation>ширина видео должна быть кратна %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/avicodecrestrictions.cpp" line="139"/>
        <source>video length must be a multiple of %1</source>
        <translation>Длина видео должна быть кратна %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/avicodecrestrictions.cpp" line="145"/>
        <source>No restrictions for this codec</source>
        <translation>Нет ограничений для этого кодека</translation>
    </message>
    <message>
        <location filename="../../toonzlib/avicodecrestrictions.cpp" line="147"/>
        <source>Resolution restrictions:</source>
        <translation>Ограничения разрешения:</translation>
    </message>
    <message>
        <location filename="../../toonzlib/tstageobjectcmd.cpp" line="85"/>
        <source>New Camera  %1</source>
        <translation>Новая камера %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/tstageobjectcmd.cpp" line="140"/>
        <source>New Pegbar  %1</source>
        <translation>Новый Pegbar  %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/tstageobjectcmd.cpp" line="187"/>
        <source>Set Active Camera  %1 &gt; %2</source>
        <translation>Выбрать активную камеру  %1 &gt; %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/tstageobjectcmd.cpp" line="245"/>
        <source>Remove Spline  %1</source>
        <translation>Удалить сплайн  %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/tstageobjectcmd.cpp" line="291"/>
        <source>New Motion Path  %1</source>
        <translation>Новая траектория  %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/tstageobjectcmd.cpp" line="334"/>
        <source>Link Motion Path  %1 &gt; %2</source>
        <translation>Траектория линии  %1 &gt; %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/tstageobjectcmd.cpp" line="460"/>
        <source>Remove Object  %1</source>
        <translation>Удалить объект  %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/tstageobjectcmd.cpp" line="546"/>
        <source>Remove Column  </source>
        <translation>Удалить столбец  </translation>
    </message>
    <message>
        <location filename="../../toonzlib/studiopalettecmd.cpp" line="47"/>
        <source>Failed to save palette.</source>
        <translation>Не удалось сохранить палитру.</translation>
    </message>
    <message>
        <location filename="../../toonzlib/studiopalettecmd.cpp" line="85"/>
        <source>Load into Current Palette  &gt; %1</source>
        <translation>Загрузка в текущую палитру  &gt; %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/studiopalettecmd.cpp" line="126"/>
        <source>Replace with Current Palette  &gt; %1</source>
        <translation>Заменить текущую палитру  &gt; %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/studiopalettecmd.cpp" line="152"/>
        <source>Delete Studio Palette  : %1</source>
        <translation>Удалить палитру Studio  : %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/studiopalettecmd.cpp" line="178"/>
        <source>Create Studio Palette  : %1</source>
        <translation>Создать палитру Studio  : %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/studiopalettecmd.cpp" line="223"/>
        <source>Delete Studio Palette Folder  : %1</source>
        <translation>Удалить папку палитры Studio  : %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/studiopalettecmd.cpp" line="247"/>
        <source>Create Studio Palette Folder  : %1</source>
        <translation>Создать папку палитры Studio  : %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/studiopalettecmd.cpp" line="267"/>
        <source>Can&apos;t undo rename palette</source>
        <translation>Не удается отменить переименование палитры</translation>
    </message>
    <message>
        <location filename="../../toonzlib/studiopalettecmd.cpp" line="268"/>
        <source>Can&apos;t undo move palette</source>
        <translation>Не удается отменить перемещение палитры</translation>
    </message>
    <message>
        <location filename="../../toonzlib/studiopalettecmd.cpp" line="280"/>
        <source>Can&apos;t redo rename palette</source>
        <translation>Не удается повторить переименование палитры</translation>
    </message>
    <message>
        <location filename="../../toonzlib/studiopalettecmd.cpp" line="281"/>
        <source>Can&apos;t redo move palette</source>
        <translation>Не удается повторить перемещение палитры</translation>
    </message>
    <message>
        <location filename="../../toonzlib/studiopalettecmd.cpp" line="294"/>
        <source>Rename Studio Palette : %1 &gt; %2</source>
        <translation>Переименовать палитру студии : %1 &gt; %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/studiopalettecmd.cpp" line="298"/>
        <source>Move Studio Palette Folder  : %1 : %2 &gt; %3</source>
        <translation>Изменить папку палитры Studio  : %1 : %2 &gt; %3</translation>
    </message>
    <message>
        <location filename="../../toonzlib/palettecmd.cpp" line="251"/>
        <source>Arrange Styles  in Palette %1</source>
        <translation>Упорядочить стили в палитре %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/palettecmd.cpp" line="322"/>
        <source>Create Style#%1  in Palette %2</source>
        <translation>Создать стиль#%1  в палитре %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/palettecmd.cpp" line="453"/>
        <source>Add Style  to Palette %1</source>
        <translation>Добавить стиль в палитру %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/palettecmd.cpp" line="671"/>
        <source>Add Page %1 to Palette %2</source>
        <translation>Добавить страницу %1 в палитру %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/palettecmd.cpp" line="736"/>
        <source>Delete Page %1 from Palette %2</source>
        <translation>Удалить  страницу %1 из палитры %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/palettecmd.cpp" line="791"/>
        <source>Load Color Model %1  to Palette %2</source>
        <translation>Загрузить цветовую %1 модель в палитру %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/palettecmd.cpp" line="889"/>
        <source>color model</source>
        <translation>Цветовая модель</translation>
    </message>
    <message>
        <location filename="../../toonzlib/palettecmd.cpp" line="1057"/>
        <source>Move Page</source>
        <translation>Переместить страницу</translation>
    </message>
    <message>
        <location filename="../../toonzlib/palettecmd.cpp" line="1108"/>
        <source>Rename Page  %1 &gt; %2</source>
        <translation>Переименовать страницу  %1 &gt; %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/palettecmd.cpp" line="1172"/>
        <source>Rename Style#%1 in Palette%2  : %3 &gt; %4</source>
        <translation>Переименование стиля#%1 в палитре%2 : %3&gt;%4</translation>
    </message>
    <message>
        <location filename="../../toonzlib/palettecmd.cpp" line="1237"/>
        <source>Set Picked Position of Style#%1 in Palette%2 : %3,%4</source>
        <translation>Установить выбранное расположение стиля#%1 в палитре%2 :%3,%4</translation>
    </message>
    <message>
        <location filename="../../toonzlib/palettecmd.cpp" line="1316"/>
        <source>Update Colors by Using Picked Positions in Palette %1</source>
        <translation>Обновление цветов с использованием выбранных расположений в палитре %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="905"/>
        <source>Add Fx  : </source>
        <translation>Добавить эффект  : </translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="906"/>
        <source>Insert Fx  : </source>
        <translation>Вставить Fx  : </translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="1068"/>
        <location filename="../../toonzlib/fxcommand.cpp" line="1071"/>
        <source>Create Linked Fx  : %1</source>
        <translation>Создать связанный Fx : %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="1293"/>
        <source>Replace Fx  : </source>
        <translation>Заменить Fx  : </translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="1359"/>
        <source>Unlink Fx  : %1 - - %2</source>
        <translation>Разъединить Fx  : %1 - - %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="1400"/>
        <source>Make Macro Fx  : %1</source>
        <translation>Сделать Makro Fx  : %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="1543"/>
        <source>Explode Macro Fx  : %1</source>
        <translation>Разбить Macro Fx  : %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="1606"/>
        <source>Create Output Fx</source>
        <translation>Создать выход Fx</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="1697"/>
        <source>Connect to Xsheet  : </source>
        <translation>Подключить к Xsheet  : </translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="1757"/>
        <source>Disconnect from Xsheet  : </source>
        <translation>Отключить от Xsheet  : </translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="2030"/>
        <source>Delete Link</source>
        <translation>Удалить связь</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="2317"/>
        <source>Delete Fx Node : %1</source>
        <translation>Удалить Fx-узел : %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="2740"/>
        <source>Paste Fx  :  </source>
        <translation>Вставить Fx :</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="3109"/>
        <source>Disconnect Fx</source>
        <translation>Отключить Fx</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="3361"/>
        <source>Connect Fx : %1 - %2</source>
        <translation>Подключить Fx : %1 - %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="3543"/>
        <source>Rename Fx : %1 &gt; %2</source>
        <translation>Переименовать Fx : %1 - %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="3595"/>
        <source>Group Fx</source>
        <translation>Сгруппировать Fx</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="3699"/>
        <source>Ungroup Fx</source>
        <translation>Разгруппировать Fx</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="3801"/>
        <source>Rename Group  : %1 &gt; %2</source>
        <translation>Переименовать группу  : %1 &gt; %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/doubleparamcmd.cpp" line="73"/>
        <source>Set Keyframe</source>
        <translation>Установить ключевой кадр</translation>
    </message>
    <message>
        <location filename="../../toonzlib/doubleparamcmd.cpp" line="816"/>
        <source>Remove Keyframe</source>
        <translation>Удалить ключевой кадр</translation>
    </message>
    <message>
        <location filename="../../toonzlib/doubleparamcmd.cpp" line="856"/>
        <source>Cycle</source>
        <translation>Цикл</translation>
    </message>
    <message>
        <location filename="../../toonzlib/tcleanupper.cpp" line="583"/>
        <source>The autocentering failed on the current drawing.</source>
        <translation>Ошибка автоцентра на текущем рисунке.</translation>
    </message>
    <message>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="160"/>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="197"/>
        <source>Move</source>
        <translation>Перемещение</translation>
    </message>
    <message>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="164"/>
        <source>Edit Rotation</source>
        <translation>Изменить поворот</translation>
    </message>
    <message>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="167"/>
        <source>Move X</source>
        <translation>Перемещение X</translation>
    </message>
    <message>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="170"/>
        <source>Move Y</source>
        <translation>Перемещение Y</translation>
    </message>
    <message>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="173"/>
        <source>Move Z</source>
        <translation>Перемещение Z</translation>
    </message>
    <message>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="176"/>
        <source>Edit Stack Order</source>
        <translation>Изменить порядок стека</translation>
    </message>
    <message>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="179"/>
        <source>Edit Scale W</source>
        <translation>Изменить масштаб W</translation>
    </message>
    <message>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="182"/>
        <source>Edit Scale H</source>
        <translation>Изменить масштаб H</translation>
    </message>
    <message>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="185"/>
        <source>Edit Scale</source>
        <translation>Изменить масштаб</translation>
    </message>
    <message>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="188"/>
        <source>Edit PosPath</source>
        <translation>Редактировать PosPath</translation>
    </message>
    <message>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="191"/>
        <source>Edit Shear X</source>
        <translation>Изменить сдвиг X</translation>
    </message>
    <message>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="194"/>
        <source>Edit Shear Y</source>
        <translation>Изменить сдвиг Y</translation>
    </message>
    <message>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="202"/>
        <source>%1  %2  Frame : %3</source>
        <translation>%1  %2  Кадр : %3</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_renderer.cpp" line="29"/>
        <source>First argument must be a scene : %1</source>
        <translation>Первым аргументом должна быть сцена :%1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_renderer.cpp" line="32"/>
        <source>Can&apos;t render empty scene</source>
        <translation>Невозможно отобразить пустую сцену</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_outline_vectorizer.cpp" line="41"/>
        <location filename="../../toonzlib/scriptbinding_centerline_vectorizer.cpp" line="43"/>
        <source>Vectorization failed</source>
        <translation>Векторизация не выполнена</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="235"/>
        <source>Argument &apos;%1&apos; does not look like a FrameId</source>
        <translation>Аргумент %1  не похож на FrameId</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image.cpp" line="205"/>
        <source>Bad argument (%1): should be an Image (not empty)</source>
        <translation>Плохой аргумент (%1): должно быть изображение (не пустой)</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_files.cpp" line="142"/>
        <source>Argument doesn&apos;t look like a file path : %1</source>
        <translation>Аргумент не похож на путь к файлу :%1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding.cpp" line="75"/>
        <source>%1-%2</source>
        <translation>%1-%2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding.cpp" line="77"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding.cpp" line="79"/>
        <source>Expected %1 argument(s) in %2, got %3</source>
        <translation>Ожидаемый %1 аргумент(ы) в %2,%3</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding.cpp" line="95"/>
        <source>%1 is not a valid color (valid color names are &apos;red&apos;, &apos;transparent&apos;, &apos;#FF8800&apos;, ecc.)</source>
        <translation>%1 не является допустимым цветом (допустимые названия цветов: &quot;красный&quot;,&quot;прозрачный,&quot;#FF8800&quot; и др.)</translation>
    </message>
    <message>
        <location filename="../../toonzlib/sceneresources.cpp" line="447"/>
        <source>Can&apos;t save</source>
        <translation>Не удается сохранить</translation>
    </message>
    <message>
        <location filename="../../toonzlib/sceneresources.cpp" line="521"/>
        <source>and %1 more item(s).</source>
        <translation>и еще%1 элемент(ов).</translation>
    </message>
    <message>
        <location filename="../../toonzlib/sceneresources.cpp" line="524"/>
        <source>Failed to save the following resources:
</source>
        <translation>Failed to save the following resources:
</translation>
    </message>
    <message>
        <location filename="../../include/toonz/stageobjectutil.h" line="133"/>
        <source>Set Keyframe   %1 at frame %2</source>
        <translation>Установить ключевой кадр %1 в кадре %2</translation>
    </message>
    <message>
        <location filename="../../include/toonz/stageobjectutil.h" line="177"/>
        <source>Remove Keyframe   %1 at frame %2</source>
        <translation>Удалить  ключевой кадр %1 в кадре %2</translation>
    </message>
    <message>
        <location filename="../../include/toonz/stageobjectutil.h" line="212"/>
        <source>Move Center   %1  Frame %2</source>
        <translation>Переместить центр   %1 кадр %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/tpalettehandle.cpp" line="40"/>
        <source>Toggle Autopaint Option  Palette : %1  Style#%2</source>
        <translation>Переключить автопокраску палитры : %1  Стиль#%2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/txshcolumn.cpp" line="689"/>
        <location filename="../../toonzlib/txshcolumn.cpp" line="717"/>
        <source>None</source>
        <translation>Отсутствует</translation>
    </message>
    <message>
        <location filename="../../toonzlib/txshcolumn.cpp" line="691"/>
        <location filename="../../toonzlib/sceneproperties.cpp" line="30"/>
        <source>Red</source>
        <translation>Красный</translation>
    </message>
    <message>
        <location filename="../../toonzlib/txshcolumn.cpp" line="693"/>
        <location filename="../../toonzlib/sceneproperties.cpp" line="34"/>
        <source>Green</source>
        <translation>Зеленый</translation>
    </message>
    <message>
        <location filename="../../toonzlib/txshcolumn.cpp" line="695"/>
        <location filename="../../toonzlib/sceneproperties.cpp" line="36"/>
        <source>Blue</source>
        <translation>Синий</translation>
    </message>
    <message>
        <location filename="../../toonzlib/txshcolumn.cpp" line="697"/>
        <source>DarkYellow</source>
        <translation>Темно-желтый</translation>
    </message>
    <message>
        <location filename="../../toonzlib/txshcolumn.cpp" line="699"/>
        <source>DarkCyan</source>
        <translation>Темный циан</translation>
    </message>
    <message>
        <location filename="../../toonzlib/txshcolumn.cpp" line="701"/>
        <source>DarkMagenta</source>
        <translation>Темно-пурпурный</translation>
    </message>
    <message>
        <location filename="../../toonzlib/cleanupcolorstyles.cpp" line="93"/>
        <source>Brightness</source>
        <translation>Яркость</translation>
    </message>
    <message>
        <location filename="../../toonzlib/cleanupcolorstyles.cpp" line="95"/>
        <source>Contrast</source>
        <translation>Контраст</translation>
    </message>
    <message>
        <location filename="../../toonzlib/cleanupcolorstyles.cpp" line="228"/>
        <source>HRange</source>
        <translation>Диапазон тона</translation>
    </message>
    <message>
        <location filename="../../toonzlib/cleanupcolorstyles.cpp" line="229"/>
        <source>Line Width</source>
        <translation>Ширина линии</translation>
    </message>
    <message>
        <location filename="../../toonzlib/cleanupcolorstyles.cpp" line="312"/>
        <source>ColorThres</source>
        <translation>Цветовой порог</translation>
    </message>
    <message>
        <location filename="../../toonzlib/cleanupcolorstyles.cpp" line="314"/>
        <source>WhiteThres</source>
        <translation>Порог яркости</translation>
    </message>
    <message>
        <location filename="../../toonzlib/orientation.cpp" line="81"/>
        <source>Xsheet</source>
        <translation>Xsheet</translation>
    </message>
    <message>
        <location filename="../../toonzlib/orientation.cpp" line="148"/>
        <source>Timeline</source>
        <translation>Таймлайн</translation>
    </message>
    <message>
        <location filename="../../toonzlib/sceneproperties.cpp" line="31"/>
        <source>Orange</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../toonzlib/sceneproperties.cpp" line="32"/>
        <source>Yellow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../toonzlib/sceneproperties.cpp" line="33"/>
        <source>Light Green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../toonzlib/sceneproperties.cpp" line="35"/>
        <source>Light Blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../toonzlib/sceneproperties.cpp" line="37"/>
        <source>Dark Blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../toonzlib/sceneproperties.cpp" line="38"/>
        <source>Purple</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../toonzlib/sceneproperties.cpp" line="39"/>
        <source>Pink</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../toonzlib/sceneproperties.cpp" line="40"/>
        <source>Dark Pink</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../toonzlib/sceneproperties.cpp" line="41"/>
        <source>White</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Rasterizer</name>
    <message>
        <source>Expected a vector image: %1</source>
        <translation type="vanished">Ожидаемое векторное изображение: %1</translation>
    </message>
    <message>
        <source>Expected a vector level: %1</source>
        <translation type="vanished">Ожидаемый векторный уровень: %1</translation>
    </message>
    <message>
        <source>Argument must be a vector level or image : </source>
        <translation type="vanished">Аргумент должен быть векторным уровнем или изображением : </translation>
    </message>
    <message>
        <source>%1 has no palette</source>
        <translation type="vanished">%1 не имеет палитры</translation>
    </message>
</context>
<context>
    <name>Scene</name>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation type="vanished">Файл %1 не существует</translation>
    </message>
    <message>
        <source>Exception reading %1</source>
        <translation type="vanished">Чтение исключений %1</translation>
    </message>
    <message>
        <source>Exception writing %1</source>
        <translation type="vanished">Запись исключений %1</translation>
    </message>
    <message>
        <source>Bad level type (%1): must be Vector,Raster or ToonzRaster</source>
        <translation type="vanished">Плохой тип уровня (%1): должен быть Vector, Raster или ToonzRaster</translation>
    </message>
    <message>
        <source>Can&apos;t add the level: name(%1) is already used</source>
        <translation type="vanished">Невозможно добавить уровень: имя(%1) уже используется</translation>
    </message>
    <message>
        <source>Can&apos;t load this kind of file as a level : %1</source>
        <translation type="vanished">Невозможно загрузить этот файл как уровень : %1</translation>
    </message>
    <message>
        <source>Could not load level %1</source>
        <translation type="vanished">Не удалось загрузить уровень %1</translation>
    </message>
    <message>
        <source>Level is not included in the scene : %1</source>
        <translation type="vanished">Уровень не включен в сцену : %1</translation>
    </message>
    <message>
        <source>%1 : Expected a Level instance or a level name</source>
        <translation type="vanished">%1 : Ожидаемый экземпляр уровня или имя уровня</translation>
    </message>
    <message>
        <source>Level &apos;%1&apos; is not included in the scene</source>
        <translation type="vanished">Уровень %1 не включен в сцену</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::CenterlineVectorizer</name>
    <message>
        <location filename="../../toonzlib/scriptbinding_centerline_vectorizer.cpp" line="69"/>
        <source>Can&apos;t vectorize a %1 level</source>
        <translation>Нельзя векторизовать уровень %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_centerline_vectorizer.cpp" line="72"/>
        <source>Can&apos;t vectorize a level with no frames</source>
        <translation>Нельзя векторизовать уровень без кадров</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_centerline_vectorizer.cpp" line="77"/>
        <source>Can&apos;t vectorize a %1 image</source>
        <translation>Нельзя векторизовать изображение %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_centerline_vectorizer.cpp" line="83"/>
        <source>Bad argument (%1): should be an Image or a Level</source>
        <translation>Недопустимый аргумент (%1): должно быть изображение или уровень</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::FilePath</name>
    <message>
        <location filename="../../toonzlib/scriptbinding_files.cpp" line="29"/>
        <source>&quot;%1&quot;</source>
        <translation>&quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_files.cpp" line="107"/>
        <source>can&apos;t concatenate an absolute path : %1</source>
        <translation>не может конкатенировать абсолютный путь: %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_files.cpp" line="115"/>
        <source>%1 is not a directory</source>
        <translation>%1 не является каталогом</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_files.cpp" line="129"/>
        <source>can&apos;t read directory %1</source>
        <translation>не удается прочитать каталог%1</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Image</name>
    <message>
        <location filename="../../toonzlib/scriptbinding_image.cpp" line="102"/>
        <source>File %1 doesn&apos;t exist</source>
        <translation>Файл %1 не существует</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image.cpp" line="126"/>
        <source>Loaded first frame of %1</source>
        <translation>Загружен первый кадр %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image.cpp" line="144"/>
        <source>Unexpected error while reading image</source>
        <translation>Ошибка при чтении изображения</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image.cpp" line="171"/>
        <source>Unrecognized file type :</source>
        <translation>Неизвестный тип файла :</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image.cpp" line="175"/>
        <source>Can&apos;t save a %1 image to this file type : %2</source>
        <translation>Не удалось сохранить изображение %1 в этот тип файла: %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image.cpp" line="196"/>
        <source>Unexpected error while writing image</source>
        <translation>Ошибка при записи изображения</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::ImageBuilder</name>
    <message>
        <location filename="../../toonzlib/scriptbinding_image_builder.cpp" line="101"/>
        <source>Bad argument (%1): should be &apos;Raster&apos; or ToonzRaster&apos;</source>
        <translation>Недопустимый аргумент (%1): должен быть &quot;Растр&quot; или &quot;ToonzRaster&quot;</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image_builder.cpp" line="138"/>
        <source>ImageBuilder(%1 image)</source>
        <translation>ImageBuilder(%1 изображение)</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image_builder.cpp" line="265"/>
        <location filename="../../toonzlib/scriptbinding_image_builder.cpp" line="285"/>
        <source>%1 : %2</source>
        <translation>%1 : %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image_builder.cpp" line="278"/>
        <source>Bad argument (%1): should be a Transformation</source>
        <translation>Плохой аргумент (%1): должно быть преобразование</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Level</name>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="67"/>
        <source>%1 frames</source>
        <translation>%1 кадров</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="122"/>
        <source>Bad argument (%1). It should be FilePath or string</source>
        <translation>Плохой аргумент (%1). Это должен быть путь файла или строка</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="130"/>
        <source>Exception loading level (%1)</source>
        <translation>Уровень загрузки исключений (%1)</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="151"/>
        <source>File %1 doesn&apos;t exist</source>
        <translation>Файл %1 не существует</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="161"/>
        <source>File %1 is unsupported</source>
        <translation>Файл %1 не поддерживается</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="170"/>
        <source>Exception reading %1</source>
        <translation>Чтение исключений %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="176"/>
        <source>Can&apos;t save an empty level</source>
        <translation>Не удалось сохранить пустой уровень</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="196"/>
        <source>Unrecognized file type :</source>
        <translation>Нераспознанный тип файла :</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="200"/>
        <source>Can&apos;t save a %1 level to this file type : %2</source>
        <translation>Не удается сохранить уровень %1 для этого типа файла : %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="209"/>
        <source>Exception writing %1</source>
        <translation>Запись исключений %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="268"/>
        <source>frame index (%1) must be a number</source>
        <translation>Индекс кадра (%1) должен быть числом</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="272"/>
        <source>frame index (%1) is out of range (0-%2)</source>
        <translation>Индекс кадра (%1) вне диапазона (0-%2)</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="295"/>
        <source>second argument (%1) is not an image</source>
        <translation>Второй аргумент (%1) не является изображением</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="308"/>
        <source>can not insert a %1 image into a level</source>
        <translation>Невозможно вставить изображение %1 в уровень</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="329"/>
        <source>can not insert a %1 image to a %2 level</source>
        <translation>Невозможно  вставить изображение %1 в уровень %2</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::OutlineVectorizer</name>
    <message>
        <location filename="../../toonzlib/scriptbinding_outline_vectorizer.cpp" line="62"/>
        <source>Can&apos;t vectorize a %1 level</source>
        <translation>Невозможно векторизовать уровень %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_outline_vectorizer.cpp" line="65"/>
        <source>Can&apos;t vectorize a level with no frames</source>
        <translation>Невозможно  векторизовать уровень без кадров</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_outline_vectorizer.cpp" line="70"/>
        <source>Can&apos;t vectorize a %1 image</source>
        <translation>Невозможно векторизовать изображение %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_outline_vectorizer.cpp" line="76"/>
        <source>Bad argument (%1): should be an Image or a Level</source>
        <translation>Плохой аргумент (%1): должно быть изображение или уровень</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_outline_vectorizer.cpp" line="175"/>
        <source>Invalid color : </source>
        <translation>Недопустимый цвет : </translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Rasterizer</name>
    <message>
        <location filename="../../toonzlib/scriptbinding_rasterizer.cpp" line="77"/>
        <source>Expected a vector image: %1</source>
        <translation>Ожидаемое векторное изображение: %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_rasterizer.cpp" line="82"/>
        <source>Expected a vector level: %1</source>
        <translation>Ожидаемый векторный уровень: %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_rasterizer.cpp" line="87"/>
        <source>Argument must be a vector level or image : </source>
        <translation>Аргумент должен быть векторным уровнем или изображением : </translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_rasterizer.cpp" line="90"/>
        <source>%1 has no palette</source>
        <translation>%1 не имеет палитры</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Scene</name>
    <message>
        <location filename="../../toonzlib/scriptbinding_scene.cpp" line="51"/>
        <source>File %1 doesn&apos;t exist</source>
        <translation>Файл %1 не существует</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_scene.cpp" line="57"/>
        <source>Exception reading %1</source>
        <translation>Чтение исключений %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_scene.cpp" line="72"/>
        <source>Exception writing %1</source>
        <translation>Запись исключений %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_scene.cpp" line="113"/>
        <source>Bad level type (%1): must be Vector,Raster or ToonzRaster</source>
        <translation>Плохой тип уровня (%1): должен быть Vector,Raster или ToonzRaster</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_scene.cpp" line="118"/>
        <location filename="../../toonzlib/scriptbinding_scene.cpp" line="129"/>
        <source>Can&apos;t add the level: name(%1) is already used</source>
        <translation>Невозможно добавить уровень: имя(%1) уже используется</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_scene.cpp" line="136"/>
        <source>Can&apos;t load this kind of file as a level : %1</source>
        <translation>Невозможно загрузить этот файл как уровень : %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_scene.cpp" line="141"/>
        <source>Could not load level %1</source>
        <translation>Не удалось загрузить уровень %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_scene.cpp" line="160"/>
        <source>Level is not included in the scene : %1</source>
        <translation>Уровень не включен в сцену : %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_scene.cpp" line="166"/>
        <source>%1 : Expected a Level instance or a level name</source>
        <translation>%1 : Ожидаемый экземпляр уровня или имя уровня</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_scene.cpp" line="171"/>
        <source>Level &apos;%1&apos; is not included in the scene</source>
        <translation>Уровень %1 не включен в сцену</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::ToonzRasterConverter</name>
    <message>
        <location filename="../../toonzlib/scriptbinding_toonz_raster_converter.cpp" line="34"/>
        <source>Can&apos;t convert a %1 level</source>
        <translation>Невозможно преобразовать уровень %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_toonz_raster_converter.cpp" line="36"/>
        <source>Can&apos;t convert a level with no frames</source>
        <translation>Невозможно преобразовать уровень без кадров</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_toonz_raster_converter.cpp" line="40"/>
        <source>Can&apos;t convert a %1 image</source>
        <translation>Невозможно преобразовать изображение %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_toonz_raster_converter.cpp" line="43"/>
        <source>Bad argument (%1): should be a raster Level or a raster Image</source>
        <translation>Плохой аргумент (%1): должен быть растровый уровень или растровое изображение</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Transform</name>
    <message>
        <location filename="../../toonzlib/scriptbinding_image_builder.cpp" line="23"/>
        <source>Identity</source>
        <translation>Идентичность</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image_builder.cpp" line="25"/>
        <location filename="../../toonzlib/scriptbinding_image_builder.cpp" line="30"/>
        <source>Translation(%1,%2)</source>
        <translation>Перемещение(%1,%2)</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image_builder.cpp" line="35"/>
        <source>Rotation(%1)</source>
        <translation>Вращение(%1)</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image_builder.cpp" line="43"/>
        <source>Scale(%1%)</source>
        <translation>Масштаб(%1%)</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image_builder.cpp" line="45"/>
        <source>Scale(%1%, %2%)</source>
        <translation>Масштаб(%1%, %2%)</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image_builder.cpp" line="53"/>
        <source>Transform(%1, %2, %3;  %4, %5, %6)</source>
        <translation>Трансформация(%1, %2, %3;  %4, %5, %6)</translation>
    </message>
</context>
<context>
    <name>ToonzRasterConverter</name>
    <message>
        <source>Can&apos;t convert a %1 level</source>
        <translation type="vanished">Невозможно преобразовать уровень %1</translation>
    </message>
    <message>
        <source>Can&apos;t convert a level with no frames</source>
        <translation type="vanished">Невозможно преобразовать уровень без кадров</translation>
    </message>
    <message>
        <source>Can&apos;t convert a %1 image</source>
        <translation type="vanished">Невозможно преобразовать изображение %1</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be a raster Level or a raster Image</source>
        <translation type="vanished">Плохой аргумент (%1): должен быть растровый уровень или растровое изображение</translation>
    </message>
</context>
<context>
    <name>Transform</name>
    <message>
        <source>Identity</source>
        <translation type="vanished">Идентичность</translation>
    </message>
    <message>
        <source>Translation(%1,%2)</source>
        <translation type="vanished">Перемещение(%1,%2)</translation>
    </message>
    <message>
        <source>Rotation(%1)</source>
        <translation type="vanished">Вращение(%1)</translation>
    </message>
    <message>
        <source>Scale(%1%)</source>
        <translation type="vanished">Масштаб(%1%)</translation>
    </message>
    <message>
        <source>Scale(%1%, %2%)</source>
        <translation type="vanished">Масштаб(%1%, %2%)</translation>
    </message>
    <message>
        <source>Transform(%1, %2, %3;  %4, %5, %6)</source>
        <translation type="vanished">Трансформация(%1, %2, %3;  %4, %5, %6)</translation>
    </message>
</context>
</TS>
